BikaClient
=============
client package for Bika Open Source LIMS project

|build|

Installation
------------

You can install the latest stable version from PyPI

.. code:: console

    $ pip install bikaclient


.. |build| image:: https://travis-ci.org/ratzeni/bikaclient.svg?branch=master
   :target: https://travis-ci.org/ratzeni/bikaclient
   :alt: Continuous Integration
